@@ -13,7 +13,7 @@ use Types::Standard qw( Value Object Ref );
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.1.1';
+our $VERSION = 'v0.1.2';
 
 
 sub import {
@@ -58,6 +58,7 @@ sub _process_has {
                 }
 
                 $opts{isa} = Const[$isa];
+                $opts{coerce} = $opts{isa}->coercion;
 
             }
 
@@ -90,13 +91,15 @@ MooX::Const - Syntactic sugar for creating constant Moo attributes
 
 =head1 VERSION
 
-version v0.1.1
+version v0.1.2
 
 =head1 SYNOPSIS
 
   use Moo;
   use MooX::Const;
 
+  use Types::Standard -types;
+
   has thing => (
     is  => 'const',
     isa => ArrayRef[HashRef],
@@ -104,7 +107,16 @@ version v0.1.1
 
 =head1 DESCRIPTION
 
-This is syntactic sugar for using L<Types::Const> with L<Moo>.
+This is syntactic sugar for using L<Types::Const> with L<Moo>. The
+SYNOPSIS above is equivalent to:
+
+  use Types::Const -types;
+
+  has thing => (
+    is     => 'ro',
+    isa    => Const[ArrayRef[HashRef]],
+    coerce => 1,
+  );
 
 It modifies the C<has> function to support "const" attributes.  These
 are read-only ("ro") attributes for references, where the underlying
